@@ -548,7 +548,7 @@ fn run_quiet(
 
     // Run the child process.
     let child = command(args).output().map_err(failure::system(format!(
-        "{} Perhaps you don't have Docker installed [1].",
+        "{} Perhaps you don't have Docker installed.",
         error,
     )))?;
 
@@ -595,7 +595,7 @@ fn run_quiet_stdin<W: FnOnce(&mut ChildStdin) -> Result<(), Failure>>(
         .stderr(Stdio::piped())
         .spawn()
         .map_err(failure::system(format!(
-            "{} Perhaps you don't have Docker installed [2].",
+            "{} Perhaps you don't have Docker installed.",
             error,
         )))?;
 
@@ -604,7 +604,7 @@ fn run_quiet_stdin<W: FnOnce(&mut ChildStdin) -> Result<(), Failure>>(
 
     // Wait for the child to terminate.
     let output = child.wait_with_output().map_err(failure::system(format!(
-        "{} Perhaps you don't have Docker installed [3].",
+        "{} Perhaps you don't have Docker installed.",
         error,
     )))?;
 
@@ -639,13 +639,13 @@ fn run_loud(error: &str, args: &[String], interrupted: &Arc<AtomicBool>) -> Resu
         .stdin(Stdio::null())
         .spawn()
         .map_err(failure::system(format!(
-            "{} Perhaps you don't have Docker installed [4].",
+            "{} Perhaps you don't have Docker installed.",
             error,
         )))?;
 
     // Wait for the child to terminate.
     let status = child.wait().map_err(failure::system(format!(
-        "{} Perhaps you don't have Docker installed [5].",
+        "{} Perhaps you don't have Docker installed.",
         error,
     )))?;
 
@@ -672,7 +672,7 @@ fn run_attach(error: &str, args: &[String], interrupted: &Arc<AtomicBool>) -> Re
 
     // Run the child process.
     let child = command(args).status().map_err(failure::system(format!(
-        "{} Perhaps you don't have Docker installed [6].",
+        "{} Perhaps you don't have Docker installed.",
         error,
     )))?;
 
